# EyeSaver

This CLI-tool will tell you when there is a change happening on the screen by beeping. Now you can close your eyes and give them a rest during those late video-lecture nights, while being sure not to miss a single bullet in the presentation you're watching. 😉
